summaryrefslogtreecommitdiff
path: root/plugins/UserInfoEx/src/dlg_propsheet.cpp
diff options
context:
space:
mode:
authorGeorge Hazan <george.hazan@gmail.com>2024-01-08 13:22:45 +0300
committerGeorge Hazan <george.hazan@gmail.com>2024-01-08 13:22:52 +0300
commitba8b5469506b3f0caeeead89028a5b61120206e3 (patch)
tree7b42564409e573fb643fb6d570b0bbf5a146de47 /plugins/UserInfoEx/src/dlg_propsheet.cpp
parentb06d84eef8004575a874486119cbefc382e94e74 (diff)
no need to call PSS_GETINFO, PSS_GETAWAYMSG, PSS_FILEALLOW, PSS_FILEDENY & PSS_FILECANCEL via Proto_ChainSend with all those filters etc, the simple call of CallContactService is enough
Diffstat (limited to 'plugins/UserInfoEx/src/dlg_propsheet.cpp')
-rw-r--r--plugins/UserInfoEx/src/dlg_propsheet.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/UserInfoEx/src/dlg_propsheet.cpp b/plugins/UserInfoEx/src/dlg_propsheet.cpp
index 28fb93902e..f14314f984 100644
--- a/plugins/UserInfoEx/src/dlg_propsheet.cpp
+++ b/plugins/UserInfoEx/src/dlg_propsheet.cpp
@@ -1225,12 +1225,12 @@ static INT_PTR CALLBACK DlgProc(HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lPar
// need meta contact's subcontact information
if (DB::Module::IsMetaAndScan(pPs->pszProto)) {
// count valid subcontacts whose protocol supports the PSS_GETINFO service to update the information
int numSubs = db_mc_getSubCount(pPs->hContact);
for (int i = 0; i < numSubs; i++) {
MCONTACT hSubContact = db_mc_getSub(pPs->hContact, i);
if (hSubContact) {
- if (ProtoServiceExists(Proto_GetBaseAccountName(hSubContact), PSS_GETINFO)) {
+ if (ProtoServiceExists(Proto_GetBaseAccountName(hSubContact), PS_GETINFO)) {
pPs->infosUpdated = (TAckInfo *)mir_realloc(pPs->infosUpdated, sizeof(TAckInfo) * (pPs->nSubContacts + 1));
pPs->infosUpdated[pPs->nSubContacts].hContact = hSubContact;
pPs->infosUpdated[pPs->nSubContacts].acks = nullptr;
@@ -1245,7 +1245,7 @@ static INT_PTR CALLBACK DlgProc(HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lPar
// call the services
for (int i = 0; i < pPs->nSubContacts; i++)
- if (!ProtoChainSend(pPs->infosUpdated[pPs->nSubContacts].hContact, PSS_GETINFO, NULL, NULL))
+ if (!CallContactService(pPs->infosUpdated[pPs->nSubContacts].hContact, PS_GETINFO))
bDo = TRUE;
if (bDo) {
@@ -1255,7 +1255,7 @@ static INT_PTR CALLBACK DlgProc(HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lPar
}
}
}
- else if (!ProtoChainSend(pPs->hContact, PSS_GETINFO, NULL, NULL)) {
+ else if (!CallContactService(pPs->hContact, PS_GETINFO)) {
pPs->infosUpdated = (TAckInfo *)mir_calloc(sizeof(TAckInfo));
pPs->infosUpdated[0].hContact = pPs->hContact;
pPs->nSubContacts = 1;
@@ -1225,12 +1225,12 @@ static INT_PTR CALLBACK DlgProc(HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lPar
// need meta contact's subcontact information
if (DB::Module::IsMetaAndScan(pPs->pszProto)) {
- // count valid subcontacts whose protocol supports the PSS_GETINFO service to update the information
+ // count valid subcontacts whose protocol supports the PS_GETINFO service to update the information
int numSubs = db_mc_getSubCount(pPs->hContact);
for (int i = 0; i < numSubs; i++) {